@@ -279,10 +279,10 @@
   #define SIZEOF_SIZE_T  SIZEOF_LONG
 #else
 /* No indentation, to fetch the lines from verification scripts */
-#define SIZEOF_LONG   4
-#define SIZEOF_VOIDP  4
-#define SIZEOF_CHARP  4
-#define SIZEOF_SIZE_T 4
+#define SIZEOF_LONG   8
+#define SIZEOF_VOIDP  8
+#define SIZEOF_CHARP  8
+#define SIZEOF_SIZE_T 8
 #endif
 
 #define HAVE_LONG 1
@@ -297,7 +297,7 @@
 /* #undef HAVE_UCHAR */
 #define SIZEOF_UINT 4
 #define HAVE_UINT 1
-#define SIZEOF_ULONG 4
+#define SIZEOF_ULONG 8
 #define HAVE_ULONG 1
 /* #undef SIZEOF_INT8 */
 /* #undef HAVE_INT8 */
@@ -399,8 +399,8 @@
 #define STACK_DIRECTION -1
 
 #define SYSTEM_TYPE "OpenBSD"
-#define MACHINE_TYPE "arm"
-#define DEFAULT_MACHINE "arm"
+#define MACHINE_TYPE "aarch64"
+#define DEFAULT_MACHINE "aarch64"
 /* #undef HAVE_DTRACE */
 
 #define SIGNAL_WITH_VIO_CLOSE 1
@@ -536,16 +536,16 @@
 
 #define MYSQL_VERSION_MAJOR 10
 #define MYSQL_VERSION_MINOR 3
-#define MYSQL_VERSION_PATCH 18
+#define MYSQL_VERSION_PATCH 22
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.3.18"
+#define PACKAGE_STRING "MySQL Server 10.3.22"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.3.18"
-#define VERSION "10.3.18"
+#define PACKAGE_VERSION "10.3.22"
+#define VERSION "10.3.22"
 #define PROTOCOL_VERSION 10
 
 #define MALLOC_LIBRARY "system"
